# Table of Contents

- [it-components-hosting-modeling-v3](<./it-components-hosting-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: IT Components / Hosting (Meta Model v3)](<./Modeling-IT-Components--Hosting-Meta-Model-v3.md>)
  - [The entry-level approach](<./Modeling-IT-Components--Hosting-Meta-Model-v3/The-entry-level-approach.md>)
  - [The pragmatic approach](<./Modeling-IT-Components--Hosting-Meta-Model-v3/The-pragmatic-approach.md>)
  - [The full-fledged approach](<./Modeling-IT-Components--Hosting-Meta-Model-v3/The-full-fledged-approach.md>)
  - [Q&A](<./Modeling-IT-Components--Hosting-Meta-Model-v3/QA.md>)
